@@ -41,7 +41,7 @@ from configured import *
 from config_version import *
 
 
-DEFAULT_PATH = ['/usr/local/sbin', '/usr/local/bin', '/usr/sbin', '/usr/bin', '/sbin', '/bin']
+DEFAULT_PATH = ['/usr/local/sbin', '/usr/local/bin', '/opt/local/sbin', '/opt/local/sbin', '/usr/sbin', '/usr/bin', '/sbin', '/bin']
 LAUNCH_DELAY = 2
 
 
@@ -160,9 +160,7 @@ class Server:
 
 class Admin:
     def halt (self):
-        parent_pid = os.getppid()
-        os.kill (parent_pid, signal.SIGTERM)
-        raise SystemExit
+        CTK.stop()
 
 
 class Support:
